summaryrefslogtreecommitdiffstats
path: root/kpat/freecell-solver/tests.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpat/freecell-solver/tests.h')
-rw-r--r--kpat/freecell-solver/tests.h18
1 files changed, 9 insertions, 9 deletions
diff --git a/kpat/freecell-solver/tests.h b/kpat/freecell-solver/tests.h
index ce0b35b5..fbf78262 100644
--- a/kpat/freecell-solver/tests.h
+++ b/kpat/freecell-solver/tests.h
@@ -58,7 +58,7 @@ extern "C" {
/* Some A* and BFS parameters that need to be initialized in \
* the derived state. \
* */ \
- ptr_new_state_with_locations->parent = ptr_state_with_locations; \
+ ptr_new_state_with_locations->tqparent = ptr_state_with_locations; \
ptr_new_state_with_locations->moves_to_parent = moves; \
/* Make sure depth is consistent with the game graph. \
* I.e: the depth of every newly discovered state is derived from \
@@ -66,8 +66,8 @@ extern "C" {
ptr_new_state_with_locations->depth = ptr_state_with_locations->depth + 1; \
/* Mark this state as a state that was not yet visited */ \
ptr_new_state_with_locations->visited = 0; \
- /* It's a newly created state which does not have children yet. */ \
- ptr_new_state_with_locations->num_active_children = 0; \
+ /* It's a newly created state which does not have tqchildren yet. */ \
+ ptr_new_state_with_locations->num_active_tqchildren = 0; \
memset(ptr_new_state_with_locations->scan_visited, '\0', \
sizeof(ptr_new_state_with_locations->scan_visited) \
); \
@@ -103,11 +103,11 @@ fcs_move_stack_push(moves, temp_move); \
{ \
fcs_state_ia_release(hard_thread); \
calculate_real_depth(existing_state); \
/* Re-parent the existing state to this one. \
* \
* What it means is that if the depth of the state if it \
* can be reached from this one is lower than what it \
* already have, then re-assign its parent to this state. \
* */ \
if (reparent && \
(existing_state->depth > ptr_state_with_locations->depth+1)) \
@@ -119,15 +119,15 @@ fcs_move_stack_push(moves, temp_move); \
); \
if (!(existing_state->visited & FCS_VISITED_DEAD_END)) \
{ \
- if ((--existing_state->parent->num_active_children) == 0) \
+ if ((--existing_state->tqparent->num_active_tqchildren) == 0) \
{ \
mark_as_dead_end( \
- existing_state->parent \
+ existing_state->tqparent \
); \
} \
- ptr_state_with_locations->num_active_children++; \
+ ptr_state_with_locations->num_active_tqchildren++; \
} \
- existing_state->parent = ptr_state_with_locations; \
+ existing_state->tqparent = ptr_state_with_locations; \
existing_state->depth = ptr_state_with_locations->depth + 1; \
} \
fcs_derived_states_list_add_state( \
@@ -103,11 +103,11 @@ fcs_move_stack_push(moves, temp_move); \
fcs_state_ia_release(hard_thread); \
calculate_real_depth(existing_state); \
- /* Re-parent the existing state to this one. \
+ /* Re-tqparent the existing state to this one. \
* \
* What it means is that if the depth of the state if it \
@@ -103,11 +103,11 @@ fcs_move_stack_push(moves, temp_move); \
* What it means is that if the depth of the state if it \
* can be reached from this one is lower than what it \
- * already have, then re-assign its parent to this state. \
+ * already have, then re-assign its tqparent to this state. \
* */ \
if (reparent && \